import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/app_registration_screen.dart';
import 'package:share_apps/screens/invitation_form.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:shared_preferences/shared_preferences.dart';

class ShareApps {
  BuildContext context;

  init(String secrateKey, String AppId, BuildContext context) {
    this.context = context;
    StringUtils.APP_ID = AppId;
    StringUtils.APP_SECRET = secrateKey;
  }

  sendInvitation() async {
    final prefs = await SharedPreferences.getInstance();
    if (prefs.getString(StringUtils.USER_DATA) == null) {
      Navigator.pushReplacement(
          context,
          MaterialPageRoute(
              builder: (context) =>
                  InvitationForm(new UserBean('', '', '', '', '', '', ''))));
    } else {
      Map jsons = json.decode(prefs.getString(StringUtils.USER_DATA));
      _showDialog(new UserBean(
          jsons['first_name'],
          jsons['last_name'],
          jsons['email'],
          jsons['phone'],
          jsons['country_id'],
          jsons['language'],
          jsons['deviceId']));
    }
  }

  Future<void> _showDialog(UserBean bean) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text('Are you continue with saved data or Edit?'),
          actions: <Widget>[
            FlatButton(
              child: Text('Edit'),
              onPressed: () {
                Navigator.of(context).pop();
                Navigator.pushReplacement(
                    context,
                    MaterialPageRoute(
                        builder: (context) => InvitationForm(bean)));
              },
            ),
            FlatButton(
              child: Text('Continue'),
              onPressed: () {
                Navigator.of(context).pop();
                openNextScreen(bean);
              },
            ),
          ],
        );
      },
    );
  }

  Future<void> openNextScreen(UserBean bean) async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        Route route = MaterialPageRoute(
            builder: (context) => AppRegistrationScreen(bean));
        Navigator.pushReplacement(context, route);
      }
    } on SocketException catch (_) {
      CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
    }
  }
}
